#
# spec file for package audacious
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define aud_plugin_ver_min 4.3
%define aud_plugin_ver_max 4.3.99
%define core_soname 5
%define qt_soname 2
%define gtk_soname 5
%define tag_soname 3
Name:           audacious
Version:        4.3.1
Release:        2.5
Summary:        Audio player with graphical UI and library functionality
License:        BSD-2-Clause
URL:            https://audacious-media-player.org/
Source:         https://distfiles.audacious-media-player.org/%{name}-%{version}.tar.bz2
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.57
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libarchive)
Requires:       %{name}-plugins%{?_isa} <= %{aud_plugin_ver_max}
Requires:       %{name}-plugins%{?_isa} >= %{aud_plugin_ver_min}
Recommends:     %{name}-plugins-extra >= %{aud_plugin_ver_min}
%if 0%{?suse_version} > 1500
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Widgets)
Requires:       cmake(Qt6Svg)
%else
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Widgets)
Requires:       cmake(Qt5Svg)
%endif

%description
Audacious is an audio player. It is based on Qt and supports a wide
range of audio codecs. It still features an alternative skinned user
interface (based on Winamp 2.x skins). Historically, it started as a
fork of a fork of XMMS.

%lang_package

%package -n libaudcore%{core_soname}
Summary:        Main functionality library of Audacious
Provides:       libaudcore%{?_isa} = %{version}

%description -n libaudcore%{core_soname}
Library from the Audacious audio player.

%package -n libaudqt%{qt_soname}
Summary:        Qt GUI implementation of Audacious
Requires:       libaudcore%{core_soname} >= %{version}

%description -n libaudqt%{qt_soname}
Library from the Audacious audio player.

%package -n libaudgui%{gtk_soname}
Summary:        GTK GUI implementation of Audacious
Requires:       libaudcore%{core_soname} >= %{version}

%description -n libaudgui%{gtk_soname}
Library from the Audacious audio player.

%package -n libaudtag%{tag_soname}
Summary:        ID3 and APE metadata support for Audacious
Requires:       libaudcore%{core_soname} >= %{version}

%description -n libaudtag%{tag_soname}
Library from the Audacious audio player.

%package devel
Summary:        Development files for Audacious
Requires:       libaudcore%{core_soname} = %{version}
Requires:       libaudgui%{gtk_soname} = %{version}
Requires:       libaudqt%{qt_soname} = %{version}
Requires:       libaudtag%{tag_soname} = %{version}

%description devel
Development files for Audacious audio player.

%prep
%setup -q

%build
%meson \
  -Dqt=true   \
%if 0%{?suse_version} > 1500
  -Dqt6=true  \
%else
  -Dqt6=false \
%endif
  -Dgtk=true  \
  -Dgtk3=true
%meson_build

%install
%meson_install

install -Dpm 0644 contrib/%{name}.appdata.xml \
  %{buildroot}%{_datadir}/metainfo/%{name}.appdata.xml

%find_lang %{name}
%fdupes %{buildroot}%{_datadir}/

%post -n libaudcore%{core_soname} -p /sbin/ldconfig

%postun -n libaudcore%{core_soname} -p /sbin/ldconfig

%post -n libaudqt%{qt_soname} -p /sbin/ldconfig

%postun -n libaudqt%{qt_soname} -p /sbin/ldconfig

%post -n libaudgui%{gtk_soname} -p /sbin/ldconfig

%postun -n libaudgui%{gtk_soname} -p /sbin/ldconfig

%post -n libaudtag%{tag_soname} -p /sbin/ldconfig

%postun -n libaudtag%{tag_soname} -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS
%{_bindir}/%{name}
%{_bindir}/audtool
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/%{name}.appdata.xml
%{_mandir}/man?/%{name}.?%{?ext_man}
%{_mandir}/man?/audtool.?%{?ext_man}

%files lang -f %{name}.lang

%files -n libaudcore%{core_soname}
%{_libdir}/libaudcore.so.%{core_soname}*

%files -n libaudqt%{qt_soname}
%{_libdir}/libaudqt.so.%{qt_soname}*

%files -n libaudgui%{gtk_soname}
%{_libdir}/libaudgui.so.%{gtk_soname}*

%files -n libaudtag%{tag_soname}
%{_libdir}/libaudtag.so.%{tag_soname}*

%files devel
%{_includedir}/%{name}/
%{_includedir}/libaudcore/
%{_libdir}/libaudcore.so
%{_includedir}/libaudqt/
%{_libdir}/libaudqt.so
%{_includedir}/libaudgui/
%{_libdir}/libaudgui.so
%{_libdir}/libaudtag.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sun Jul 23 2023 Christoph G <foss@grueninger.de>
- Require Qt(5/6)Svg, otherwise the Qt version does not show icons.
* Sun Jun 11 2023 Christoph G <foss@grueninger.de>
- Update to version 4.3.1:
  * See https://audacious-media-player.org/news/57-audacious-4-3-1-released
* Tue Mar  7 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.3:
  * See https://audacious-media-player.org/news/56-audacious-4-3-released
- Add the libarchive build requirement.
- Switch to Qt 6 on openSUSE newer than 15.x
- Switch to GTK 3.
* Wed Jul 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.2:
  * New and improved features:
  - Add a built-in dark theme using Qt's Fusion style (default on
    Windows)
  - Add a dark theme-friendly variant of the built-in fallback
    icons, and make both built-in icon sets user-selectable
  - Add partial support for Ogg FLAC streams
  - Preselect the filename of an imported playlist when exporting
    it again
  - Automatically set the title of an imported playlist based on
    the filename
  - Add a Search and Select dialog to the Winamp interface in Qt
    mode
  - Add a Jump to Song dialog to the Winamp interface in Qt mode
  - Add formatter syntax to allow truncating title strings
  * Bugs fixed since 4.1:
  - Fix some fluidsynth settings not working
  - Add checks to prevent Open Containing Folder from being
    abused to open other types of file
  - Fix a crash in the bundled Game_Music_Emu library's SNES
    emulation
  - Fix the Winamp interface not minimizing from the Windows
    taskbar
  - Fix .mkv files being skipped when opening a folder
  - Prevent the Qt interface from popping up multiple error
    dialogs
  * Bugs fixed since 4.2-beta1:
  - Don't switch to FileWriter output when no other outputs are
    available
  - Update for compatibility with FFmpeg 5.0
  - Fix hang when reaching the end of some files using FFmpeg
  - Fix playlist unexpectedly scrolling in Winamp interface
  - Prevent crash in 3rd-party QtPBFImagePlugin when using Winamp
    interface
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.1:
  * Switching between Qt and GTK modes can now be done right from
    the Settings window, without editing .desktop files.
  * New Global Hotkeys plugin for Qt
  * Album art in the info bar can be disabled
  * Symbolic links are now followed when adding folders
  * The currently playing track is displayed in bold font
  * The playlist drag-and-drop indicator is now more visible
  * Queue Manager, Equalizer, and Equalizer Presets windows are
    now dockable
  * Entry, Track, and Queue Number columns now display abbreviated
    header text
  * The Song Info window now displays channel count
  * The mouse wheel can be used to seek in the Qt UI
  * The Channel Mixer can now convert 2 to 4 channels
  * Desktop notifications can have a custom timeout set
  * Scrobbler submissions now include album artist
  * Fixed: Cuesheet entries read incorrectly from .m3u playlists
  * Fixed: Null pointer dereference in Lyrics plugin
  * Fixed: Album cover image does not display from ID3v2.2 tag
  * Fixed: Crash in headless mode with status icon enabled
  * New translations: Albanian, Slovenian
  * Support for the LyricWiki database, which has shut down,
    has been removed
- Now builds with GTK frontend per default
* Wed Jul 15 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.0.5:
  * See https://audacious-media-player.org/news/50-audacious-4-0-5-released
* Wed Jun  3 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.0.4:
  * See https://audacious-media-player.org/news/49-audacious-4-0-4-released
* Thu Apr 30 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.0.3:
  * See https://audacious-media-player.org/news/48-audacious-4-0-3-released
* Wed Apr 15 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.0.2:
  * Fix a regression where the Enter key did not work in the
    playlist.
  * Fix the seek bar changing width as the time counter increments.
  * Fix the title bar getting stuck showing "Buffering".
  * Add a workaround to ensure that the toolbar is not hidden on
    startup.
  * Fix the Composer field not being saved when updating ID3v2
    tags.
* Mon Apr  6 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.0.1:
  * Audacious now works as expected when run under KDE Plasma 5.18
    default settings.
  * Audacious when running under QtUI will no longer block logout
    on KDE Plasma 5.18.
  * Skinned windows are placed correctly when running under GTK.
* Sun Mar 22 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.0:
  * See https://audacious-media-player.org/news/45-audacious-4-0-released
- Disable building the deprecated GTK UI.
- Build with Meson.
* Wed Dec 26 2018 sor.alexei@meowr.ru
- Update to version 3.10.1:
  * Bug fixes.
* Thu Aug  9 2018 sor.alexei@meowr.ru
- Update to version 3.10:
  + New features (general):
  * Shuffle history is remembered at exit to avoid repeating
    songs.
  * Exported M3U and PLS playlists now use relative paths by
    default.
  * Recursively adding subdirectories to the playlist is now
    optional.
  * The URL history shown in the Add/Open URL dialogues can be
    cleared.
  * Toolbar buttons in the GTK+ UI now show tooltip hints.
  * The adplug input plugin has a new settings window.
  * The Search Tool can be configured to scan for new files at
    start-up.
  * The number of results shown in the Search Tool is now
    configurable.
  * The Delete Files plugin is clearer about which files will be
    deleted.
  * Icons from the desktop theme are used more consistently.
  * The bottom info bar now matches the colour tone of dark
    themes.
  * The soxr resampler has some new, more detailed settings.
  + Qt UI enhancements:
  * "audacious -m" now raises the main window as expected.
  * The number pad Enter key now starts playback as expected.
  * The Escape key can be used to return to the currently playing
    playlist.
  * Fix the row height of the playlist view changing
    unexpectedly.
  * Volume can be changed using the mouse wheel on the system
    tray icon.
  * Add Playlist Import/Export dialogue windows.
  * Add a song info tooltip to the playlist and system tray icon.
  * Add a "Play" icon to the tab of the currently playing
    playlist.
  * Add a label showing file path/URI to the song info window.
  * URI and tag values in the song info window can be copied to
    the clipboard.
  * Add the missing "Search Library" command in the Winamp UI.
  * Add font formatting to improve readability in the
    Search Tool.
  * Fix a build error (QStaticText-related) with Qt 5.10.
  * Fix Audacious exiting when the settings window is closed.
  * Fix font preferences not being respected in a couple of
    places.
  * Fix playlist position sometimes not updating when the song
    changes.
  * The info bar correctly changes colour when the theme changes.
  + Bugs fixed:
  * Non-existent files are no longer skipped when loading a
    playlist.
  * Fix an issue when trying to seek beyond the end of a WAV
    file.
  * The default ReplayGain amplification for untagged files works
    again.
  * Fix a crash when changing UI with the Ampache plugin enabled.
  * Fix a crash on exit when using the Winamp UI and the Ampache
    plugin.
  * Fix a warning about --datarootdir when running ./configure.
  * Reduce excessive file I/O when loading playlists.
  * Fix repeated error messages when playing a short playlist on
    repeat.
  * PulseAudio users can now change the volume without a song
    playing.
  * Fix an error preventing FLAC tags from being updated.
  * Add a .m4v extension to the whitelist so that audio can be
    played.
  * Fix a rare crash triggered by a specific sequence of playlist
    edits.
  * Fix incorrect "Recording On/Off" notifications in the
    Winamp UI.
  * Fix an error in the MPRIS 2 server affecting the playerctl
    client.
  + Other changes:
  * The GNOME Shortcuts plugin, which has been broken since
    GNOME 3.26, is gone.
  * The system version of the AdPlug library is now used
    (if installed).
  * Audacious no longer registers as an inode/directory MIME
    type handler.
- Remove audacious-no-inode-directory-mimetype.patch: fixed
  upstream.
- Switch back to Gtk2 from Gtk3 for the Gtk3 version is gone.
* Sun Oct 29 2017 olaf@aepfle.de
- Remove the versioned conditional for Qt build.
  It builds fine in PackageHub, and audacious-plugins expects the
  Qt variant.
- Remove Qt and GTK conditionals, they are always enabled and the
  name is too generic
- Remove conditional for appdata for obsolete Leap 42.1
* Wed Aug 23 2017 aloisio@gmx.com
- Update to version 3.9
  Qt UI enhancements:
  * More configurable main window, with new View menu and
    additional options in Settings (#657)
  * Full drag-and-drop capability for playlist entries
  * Configurable playlist columns (add, remove, resize, and
    rearrange)
  * New controls for stream recording
  * Improved playlist search bar, which hides until Control+F is
    pressed, matches results more intelligently, and even mimics
    the keyboard controls of the old 'Jump to Song' dialog
  * Integrated menu items and keyboard shortcuts for the
    Playlist Manager and Search Tool
  * More detailed yet unobtrusive reporting of errors via the
    status bar
  * Visual indication when 'Stop After This Song' is active, by
    making the stop button a toggle
  * Better high-DPI support and many other cosmetic fixes
  Usability improvements:
  * A Comments column can be displayed in the playlist, and used
    to sort it (#560)
  * Bold, italics, and capitals highlight different types of
    results in the GTK+ version of the Search Tool (#701)
  * The Record button is hidden to prevent accidental usage
    until recording is enabled in Settings (#703)
  * Recording settings can be changed without immediately
    starting to record the currently playing stream
  * The unhelpful "Unknown playback error" message has been
    removed
  Advanced features:
  * audtool gains better support for multiple playlists with the
  - -select-displayed and --select-playing commands (#609)
  * Recursive adding of folders specified in M3U playlists (#731)
  * Direct output to ALSA devices that require packed 24-bit
    audio
  * Automatic switching between track and album ReplayGain modes
    when shuffle is enabled/disabled
  * Option in Speed and Pitch effect to adjust both parameters
    in lockstep, thereby preventing distortion
  Under the hood:
  * Conversion of a substantial amount of C-like code to safer
    C++ practices
  * For the Windows build, an update to the newer MinGW-w64
    toolchain (still 32-bit)
- Changed source URL
* Tue May 16 2017 jengelh@inai.de
- Ensure neutrality of description.
  Update package summaries so they are not all the same.
* Thu Jan 26 2017 sor.alexei@meowr.ru
- Update to version 3.8.2:
  * No changelog available.
* Wed Dec  7 2016 sor.alexei@meowr.ru
- Update to version 3.8.1:
  * No changelog available.
- Rebase audacious-no-inode-directory-mimetype.patch
* Fri Sep 23 2016 sor.alexei@meowr.ru
- Update to version 3.8:
  * No changelog available.
- Rebase audacious-no-inode-directory-mimetype.patch
- Install the appstream file to /usr/share/metainfo/ instead of
  /usr/share/appdata/ on openSUSE Leap 42.2 and newer.
* Tue Mar 29 2016 sor.alexei@meowr.ru
- Update to 3.7.2.
* Fri Mar 25 2016 i@marguerite.su
- fix boo#972690: audacious is used to open directory
- add patch: audacious-no-inode-directory-mimetype.patch
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 3.7.1.
* Fri Nov 13 2015 aloisio@gmx.com
- Fixes audacious-plugins build on 13.1
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 3.7.
- Enable Qt UI.
* Fri Aug 21 2015 sor.alexei@meowr.ru
- Work with Audacious plugin versions instead of ABI versions to
  simplify things a lot.
* Mon Jun  1 2015 sor.alexei@meowr.ru
- Update to 3.6.2.
* Sat Apr  4 2015 sor.alexei@meowr.ru
- Update to 3.6.1.
* Sun Mar  1 2015 sor.alexei@meowr.ru
- Update to 3.6.
* Sun Dec 28 2014 sor.alexei@meowr.ru
- Update to 3.5.2.
- Spec cleanup.
* Tue Dec 17 2013 reddwarf@opensuse.org
- Update to 3.4.2
* Fri Mar 29 2013 fisiu@opensuse.org
- Update to 3.3.4:
  * Ported from gtk2 to gtk3
  * Save current track position
  * Improved search feature
  * Many bug fixes
* Sun Aug 19 2012 seife+obs@b1-systems.com
- update to current version 3.2.4
- removed no longer necessary -lgmodule-2.0 hack
* Tue May 22 2012 seife+obs@b1-systems.com
- fix build on > 12.1 by adding -lgmodule-2.0 to LIBS
* Fri Dec  9 2011 detlef@links2linux.de
- new upstream version <3.1.1>
* Sun Nov 20 2011 pascal.bleser@opensuse.org
- update to 3.1
* Sun Nov  6 2011 detlef@links2linux.de
- new upstream version <3.0.3>
* Sun Aug 28 2011 detlef@links2linux.de
- new upstream version <3.0.2>
* Sat Aug 13 2011 detlef@links2linux.de
- new upstream version <3.0.1>
* Sat Jul  2 2011 detlef@links2linux.de
- new upstream version <2.5.3>
* Thu Jun 23 2011 detlef@links2linux.de
- new upstream version <2.5.2>
* Sat May 21 2011 detlef@links2linux.de
- new upstream version <2.5.1>
* Sun Apr 17 2011 detlef@links2linux.de
- new upstream version <2.5.0>
* Wed Feb 23 2011 detlef@links2linux.de
- new upstream version <2.4.4>
* Fri Jan 14 2011 detlef@links2linux.de
- new upstream version <2.4.3>
* Wed Dec  8 2010 detlef@links2linux.de
- new upstream version <2.4.2>
* Fri Aug 27 2010 detlef@links2linux.de
- enable libguess support
* Wed Aug 25 2010 detlef@links2linux.de
- new upstream version <2.4-rc3>
* Fri Apr  9 2010 detlef@links2linux.de
- new upstream version <2.3>
* Wed Nov 25 2009 detlef@links2linux.de
- new upstream version <2.2>
* Wed Jul  8 2009 Manfred.Tremmel@iiv.de
- new upstream version <2.1>
* Fri Jun  5 2009 Manfred.Tremmel@iiv.de
- new upstream version <2.0.1>
* Tue Jul 22 2008 guru@unixtech.be
- added InitialPreference to action_audacious.desktop as it is
  associated with directories, in order to avoid it being the
  default action on directories
- added patch to fix specifying files on the command-line when
  audacious isn't already running:
  http://bugzilla.atheme.org/show_bug.cgi?id=48
* Sun Jul 20 2008 detlef@links2linux.de
- require audacious-plugins instead of audacious-plugins-option
  package managers are stupid ;)
* Thu Jul 10 2008 guru@unixtech.be
- require audacious-plugins-option instead of audacious-plugins
* Sun Jul  6 2008 guru@unixtech.be
- split shared libraries into its own -libs subpackage to avoid the
  chicken/egg problem when building audacious and audacious-plugins
  (as they both require each other), with audacious now requiring
  audacious-libs
- minor spec file cleanups
- added Provides for shlibs, openSUSE Shared Library Policy compliant
- more explicit filenames in files sections
- better Summary
- added glib backport patch to build on openSUSE 10.2
* Mon May 26 2008 detlef@links2linux.de
- new upstream version <1.5.1>
* Tue Apr 22 2008 detlef@links2linux.de
- fix Requires for devel
* Sun Mar 30 2008 detlef@links2linux.de
- disable ss2 for ix86, some old cpus doesn't support sse2
* Sat Mar 15 2008 detlef@links2linux.de
- new upstream version <1.5.0>
* Mon Feb 18 2008 detlef@links2linux.de
- rebuild with new libmcs-0.7
* Fri Feb  1 2008 detlef@links2linux.de
- new upstream version <1.4.6>
* Sat Dec 29 2007 detlef@links2linux.de
- new upstream version <1.4.5>
* Sat Dec 22 2007 detlef@links2linux.de
- rebuild for new libmcs and libmowgli
* Sat Dec  8 2007 detlef@links2linux.de
- add servicemenu for konqueror and dolphin
* Mon Dec  3 2007 detlef@links2linux.de
- new upstream version <1.4.4>
* Sat Dec  1 2007 detlef@links2linux.de
- new upstream version <1.4.3>
* Mon Nov 19 2007 detlef@links2linux.de
- new upstream release <1.4.1>
* Tue Nov  6 2007 detlef@links2linux.de
- new upstream release <1.4.0>
* Mon Nov  5 2007 detlef@links2linux.de
- switch to 1.4 on PackMan
- Audacious 1.4 is now complete, and is now recommended over 1.3
* Fri Nov  2 2007 detlef@links2linux.de
- new upstream release <1.4.0-rc1>
* Mon Oct 29 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta4>
* Fri Oct 19 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta2>
* Mon Oct 15 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta1>
* Thu Sep 20 2007 detlef@links2linux.de
- add xchat-plugin
* Thu Sep 13 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr4>
* Sun Sep  9 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr3>
* Thu Aug  9 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr2>
- fix BuildRequires -> add dbus-support
* Mon Jul 23 2007 detlef@links2linux.de
- initial build <1.4.0-dr1>
